@@ -1,5 +1,5 @@
 
-__version__ = "0.2.21"
+__version__ = "0.2.22"
 __common_alias__ = "nsbatwm"
 
 from napari.types import ImageData, LabelsData
@@ -264,7 +264,7 @@ def connected_component_labeling(binary_image: LabelsData, exclude_on_edges: boo
     """
     if exclude_on_edges:
         # processing the image, which is not a timelapse
-        return label(clear_border(np.asarray(binary_image)))
+        return remove_labels_on_edges(label(np.asarray(binary_image)))
 
     else:
         return label(np.asarray(binary_image))
@@ -281,7 +281,9 @@ def remove_labels_on_edges(label_image: LabelsData, viewer: napari.Viewer = None
     ..[0] https://scikit-image.org/docs/stable/api/skimage.segmentation.html#skimage.segmentation.clear_border
     """
 
-    return clear_border(np.asarray(label_image))
+    result = clear_border(np.asarray(label_image))
+    relabeled_result, _, _ = relabel_sequential(result)
+    return relabeled_result
 
 
 @register_function(menu="Segmentation post-processing > Expand labels (scikit-image, nsbatwm)")
@@ -362,7 +364,7 @@ def gauss_otsu_labeling(image:ImageData, outline_sigma: float = 2, viewer: napar
     return labels
 
 
-@register_function(menu="Segmentation / labeling > Seeded watershed (scikit-image, nsbatwm)")
+@register_function(menu="Segmentation post-processing > Seeded watershed (scikit-image, nsbatwm)")
 @time_slicer
 def seeded_watershed(membranes:ImageData, labeled_nuclei:LabelsData, viewer: napari.Viewer = None) -> LabelsData:
     """
